************
Installation
************

On Debian Linux and Debian-based distributions like Ubuntu or
Raspbian, install the ``mopidy-podcast`` package from
apt.mopidy.com_::

  apt-get install mopidy-podcast

Otherwise, install the Python package from PyPI_::

  pip install Mopidy-Podcast


.. _PyPI: https://pypi.python.org/pypi/Mopidy-Podcast/
.. _apt.mopidy.com: http://apt.mopidy.com/
